@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2013 Novell, Inc.
+ * Copyright (c) 2023 SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -24,13 +25,27 @@
 #define SNAPPER_VERSION_H
 
 
-#define LIBSNAPPER_MAJOR="6"
-#define LIBSNAPPER_MINOR="0"
-#define LIBSNAPPER_PATCHLEVEL="1"
+#define LIBSNAPPER_VERSION_STRING "7.4.4"
 
-#define LIBSNAPPER_VERSION ( LIBSNAPPER_MAJOR * 10000 + \\
-			     LIBSNAPPER_MINOR * 100 + \\
-			     LIBSNAPPER_PATCHLEVEL )
+#define LIBSNAPPER_MAJOR "7"
+#define LIBSNAPPER_MINOR "4"
+#define LIBSNAPPER_PATCHLEVEL "4"
+
+#define LIBSNAPPER_VERSION_AT_LEAST(major, minor)                                            \
+    ((LIBSNAPPER_VERSION_MAJOR > (major)) ||                                                 \
+     (LIBSNAPPER_VERSION_MAJOR == (major) && LIBSNAPPER_VERSION_MINOR >= (minor)))
+
+
+namespace snapper
+{
+
+    /**
+     * Return LIBSNAPPER_VERSION_STRING libsnapper was compiled with. May differ
+     * from the define (compile time vs. link time).
+     */
+    const char* get_libversion_string();
+
+}
 
 
 #endif
